-- Copyright (C) GIANTS Software GmbH, Confidential, All Rights Reserved.

EmissiveControl = {};
EmissiveControl_mt = Class(EmissiveControl, Placeable);

InitObjectClass(EmissiveControl, "EmissiveControl");


function EmissiveControl:new(isServer, isClient, customMt)
    local mt = customMt;
    if mt == nil then
        mt = EmissiveControl_mt;
    end;

    local self = Placeable:new(isServer, isClient, mt);

    registerObjectClassName(self, "EmissiveControl");

    return self;
end;

function EmissiveControl:delete()
    unregisterObjectClassName(self);
    EmissiveControl:superClass().delete(self);

    if g_currentMission.environment ~= nil then
        g_currentMission.environment:removeWeatherChangeListener(self);
    end;
end;

function EmissiveControl:finalizePlacement()
    EmissiveControl:superClass().finalizePlacement(self);
    g_currentMission.environment:addWeatherChangeListener(self);
    self:weatherChanged()
end

function EmissiveControl:load(xmlFilename, x,y,z, rx,ry,rz, initRandom)
    if not EmissiveControl:superClass().load(self, xmlFilename, x,y,z, rx,ry,rz, initRandom) then
        return false;
    end;

    self.elements = {};
    for i=0, getNumOfChildren(self.nodeId)-1 do
        local element = {};

        element.node = getChildAt(self.nodeId, i)
        --element.nodeMat = getMaterial(element.node, 0)
        --print(getName(element.node))
        --print(getName(getChildAt(element.node, 0)))
        --element.nodeNightMat = getMaterial(getChildAt(element.node, 0), 0)
        --print(element.nodeMat .. " - " .. tostring(element.nodeNightMat))

        table.insert(self.elements, element)
    end

    return true;
end;

function EmissiveControl:weatherChanged()
    --print("called")
    --if g_currentMission.environment.isSunOn then
        for _, element in pairs(self.elements) do
            --print(getName(element.node))
			local day = getChildAt(element.node, 0);
			local night = getChildAt(element.node, 1);
			--true at day, false at night
			setVisibility(day, g_currentMission.environment.isSunOn);
			--false at day, true at night
			setVisibility(night, not g_currentMission.environment.isSunOn);
            --setMaterial(element.node, element.nodeMat, 0)
        end;
--[[    else
        for _, element in pairs(self.elements) do
            print(getName(element.node))
			local child = getChildAt(element.node, 0);
			--setVisibility(element.node, true);
			setVisibility(child, true);
            --setMaterial(element.node, element.nodeNightMat, 0)
        end
    end]]
end;

registerPlaceableType("EmissiveControl", EmissiveControl);